@@ -123,7 +123,7 @@ class DocsBuilder(object):
             group_values = self.group_map.setdefault(group_name, [])
             group_values.append(package_name)
 
-        self.z3csphinx_packages = []
+        self.z3csphinx_packages = {}
         if self.options.z3csphinx_output_directory:
             root_pkgs = os.listdir(self.options.z3csphinx_output_directory)
 
@@ -133,9 +133,10 @@ class DocsBuilder(object):
                                        , 'build'
                                        , pkg_name
                                        )
-                self.z3csphinx_packages.append(pkg_name)
-                self.packages[pkg_name] = {self.options.trunk_name: pkg_docs}
+                self.z3csphinx_packages[pkg_name] = pkg_docs
 
+                if not self.options.urls:
+                    self.packages[pkg_name] = {self.options.trunk_name: pkg_docs}
 
     def run(self):
         grouped = []
@@ -151,6 +152,9 @@ class DocsBuilder(object):
 
             if package_name not in self.z3csphinx_packages:
                 self.build_html(package_name)
+            else:
+                pkg_docs = self.z3csphinx_packages.get(package_name)
+                self.packages[package_name][self.options.trunk_name] = pkg_docs
             self.link_html(package_name)
 
         if self.options.index_template:
@@ -274,7 +278,8 @@ class DocsBuilder(object):
             doc_folder = None
             for folder_name in self.options.docs_folders:
                 doc_candidate = os.path.join(tag_folder, folder_name)
-                if os.path.isdir(doc_candidate):
+                if ( os.path.isdir(doc_candidate) and 
+                     os.path.isfile(os.path.join(doc_candidate, 'conf.py')) ):
                     doc_folder = doc_candidate
                     break
 
@@ -344,6 +349,9 @@ class DocsBuilder(object):
         pythonpath = ':'.join(sys.path)
         self.packages[package_name] = {}
 
+        if package_name in self.z3csphinx_packages:
+            return package_name
+
         if not os.path.isdir(package_dir):
             os.mkdir(package_dir)
 
@@ -357,7 +365,9 @@ class DocsBuilder(object):
             self._do_shell_command(cmd)
         cmd = 'PYTHONPATH="%s" %s %s/setup.py egg_info' % (
                 pythonpath, sys.executable, trunk_path)
-        self._do_shell_command(cmd, fromwhere=trunk_path)
+
+        if os.path.isdir(trunk_path):
+            self._do_shell_command(cmd, fromwhere=trunk_path)
         self.packages[package_name][self.options.trunk_name] = None
 
         if not self.options.trunk_only:
